### Name: AdMit
### Title: Adaptive Mixture of Student-t Distributions
### Aliases: AdMit
### Keywords: htest

### ** Examples

  ## Gelman and Meng (1991) kernel function
  GelmanMeng <- function(x, A = 1, B = 0, C1 = 3, C2 = 3, log = TRUE)
  {
    if (is.vector(x))
      x <- matrix(x, nrow = 1)
    r <- -.5 * (A * x[,1]^2 * x[,2]^2 + x[,1]^2 + x[,2]^2
              - 2 * B * x[,1] * x[,2] - 2 * C1 * x[,1] - 2 * C2 * x[,2])
    if (!log)
      r <- exp(r)
    as.vector(r)
  }

  ## Run AdMit (with default values)
  set.seed(1234)
  outAdMit <- AdMit(GelmanMeng, mu0 = c(0.0, 0.1))
  print(outAdMit)

  ## Run AdMit (using importance sampling to estimate
  ## the modes and the scale matrices)
  set.seed(1234)
  outAdMit <- AdMit(KERNEL = GelmanMeng, 
                    mu0 = c(0.0, 0.1), 
                    control = list(IS = TRUE))
  print(outAdMit)

  ## Simple econometric model: y_t ~ i.i.d. N(mu,sigma^2)
  ## Jeffreys prior p(theta) prop 1/sigma for sigma > 0
  KERNEL <- function(theta, y, log = TRUE)
  {
    if (is.vector(theta))
      theta <- matrix(theta, nrow = 1)

    KERNEL_sub <- function(thetai)
    {
      if (thetai[2] > 0)
        {
          r <- - log(thetai[2]) + sum(dnorm(y, thetai[1], thetai[2], TRUE))
        }
      else
        {
          r <- -Inf
        }
      as.numeric(r)
    }
    r <- apply(theta, 1, KERNEL_sub)
    if (!log)
      r <- exp(r)
    as.numeric(r)
  }

  ## Generate 20 draws for mu = 1 and sigma = 0.5
  set.seed(1234)
  y <- rnorm(20, 2, 0.5)

  ## Run AdMit (with default values); pass the vector y
  ## of observations using the ... argument of AdMit and
  ## print steps of the fitting process
  outAdMit <- AdMit(KERNEL = KERNEL, 
                    mu0 = c(1.0, 1.0), 
                    y = y, control = list(trace = TRUE))
  print(outAdMit)



